@@ -1,9 +1,7 @@
 from .async_http import request
 from .async_event import Event
-from .async_executor import ThreadEventLoopPolicy
 from alliancepy.season import Season
 import asyncio
-import nest_asyncio
 from concurrent.futures import ThreadPoolExecutor
 import re
 
@@ -60,7 +58,6 @@ class Team:
         self._team_number = team_number
         self._headers = headers
         self._loop = asyncio.get_event_loop()
-        nest_asyncio.apply(self._loop)
         team = self._loop.run_until_complete(
             request(target=f"/team/{team_number}", headers=headers)
         )
@@ -107,7 +104,6 @@ class Team:
 
             return ed
 
-        asyncio.set_event_loop_policy(ThreadEventLoopPolicy())
         loop = asyncio.get_event_loop_policy().new_event_loop()
         future = loop.run_in_executor(ThreadPoolExecutor(), _parse_events)
         return loop.run_until_complete(future)
